@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::AddPrereqs;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-07-22'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -126,6 +126,11 @@ sub munge_file {
 
     my ($self, $file) = @_;
 
+    unless ($file->isa("Dist::Zilla::File::OnDisk")) {
+        $self->log_debug(["skipping %s: not an ondisk file, currently only ondisk files are processed", $file->name]);
+        return;
+    }
+
     state $pa = Perinci::Access->new;
 
     local @INC = ('lib', @INC);
@@ -199,7 +204,7 @@ Dist::Zilla::Plugin::Rinci::AddPrereqs - Add prerequisites from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.09 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2016-06-02.
+This document describes version 0.10 of Dist::Zilla::Plugin::Rinci::AddPrereqs (from Perl distribution Dist-Zilla-Plugin-Rinci-AddPrereqs), released on 2016-07-22.
 
 =head1 SYNOPSIS
 
